import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnInit, QueryList, TemplateRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { IgxCheckboxComponent } from '../checkbox/checkbox.component';
import { IgxSelectionAPIService } from '../core/selection';
import { IgxStringFilteringOperand, IgxBooleanFilteringOperand } from '../data-operations/filtering-condition';
import { FilteringLogic } from '../data-operations/filtering-expression.interface';
import { SortingDirection } from '../data-operations/sorting-expression.interface';
import { IForOfState } from '../directives/for-of/for_of.directive';
import { IgxDropDownItemBase } from '../drop-down/drop-down-item.component';
import { IgxComboDropDownComponent } from './combo-dropdown.component';
export declare enum DataTypes {
    EMPTY = "empty",
    PRIMITIVE = "primitive",
    COMPLEX = "complex",
    PRIMARYKEY = "valueKey",
}
export interface IComboSelectionChangeEventArgs {
    oldSelection: any[];
    newSelection: any[];
    event?: Event;
}
export interface IComboItemAdditionEvent {
    oldCollection: any[];
    addedItem: any;
    newCollection: any[];
}
export declare class IgxComboComponent implements AfterViewInit, ControlValueAccessor, OnInit {
    protected elementRef: ElementRef;
    protected cdr: ChangeDetectorRef;
    protected selectionAPI: IgxSelectionAPIService;
    id: string;
    /**
     * @hidden
     */
    customValueFlag: boolean;
    /**
     * @hidden
     */
    defaultFallbackGroup: string;
    /**
     * @hidden
     */
    protected stringFilters: typeof IgxStringFilteringOperand;
    /**
     * @hidden
     */
    protected boolenFilters: typeof IgxBooleanFilteringOperand;
    /**
     * @hidden
     */
    protected _filteringLogic: FilteringLogic;
    /**
     * @hidden
     */
    protected _filteringExpressions: any[];
    /**
     * @hidden
     */
    protected _sortingExpressions: any[];
    /**
     * @hidden
     */
    protected _groupKey: string | number;
    /**
     * @hidden
     */
    protected _displayKey: string | number;
    private _dataType;
    private _filteredData;
    private _children;
    private _dropdownContainer;
    private _searchInput;
    private _comboInput;
    private _width;
    private _onChangeCallback;
    private overlaySettings;
    private _value;
    private _searchValue;
    constructor(elementRef: ElementRef, cdr: ChangeDetectorRef, selectionAPI: IgxSelectionAPIService);
    /**
     * @hidden
     */
    dropdown: IgxComboDropDownComponent;
    /**
     * @hidden
     */
    selectAllCheckbox: IgxCheckboxComponent;
    /**
     * @hidden
     */
    /**
     * @hidden
     */
    searchInput: ElementRef<HTMLInputElement>;
    /**
     * @hidden
     */
    /**
     * @hidden
     */
    comboInput: ElementRef<HTMLInputElement>;
    /**
     * @hidden
     */
    protected primitiveTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    protected complexTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    emptyTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    headerTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    footerTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    itemTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    addItemTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    headerItemTemplate: TemplateRef<any>;
    /**
     * @hidden
     */
    /**
     * @hidden
     */
    protected dropdownContainer: ElementRef;
    /**
     * @hidden
     */
    /**
     * @hidden
     */
    children: QueryList<IgxDropDownItemBase>;
    /**
     * Emitted when item selection is changing, before the selection completes
     *
     * ```html
     * <igx-combo (onSelectionChange)='handleSelection()'></igx-combo>
     * ```
     */
    onSelectionChange: EventEmitter<IComboSelectionChangeEventArgs>;
    /**
     * Emitted before the dropdown is opened
     *
     * ```html
     * <igx-combo onOpening='handleOpening()'></igx-combo>
     * ```
     */
    onOpening: EventEmitter<{}>;
    /**
     * Emitted after the dropdown is opened
     *
     * ```html
     * <igx-combo (onOpened)='handleOpened()'></igx-combo>
     * ```
     */
    onOpened: EventEmitter<{}>;
    /**
     * Emitted before the dropdown is closed
     *
     * ```html
     * <igx-combo (onClosing)='handleClosing()'></igx-combo>
     * ```
     */
    onClosing: EventEmitter<{}>;
    /**
     * Emitted after the dropdown is closed
     *
     * ```html
     * <igx-combo (onClosed)='handleClosed()'></igx-combo>
     * ```
     */
    onClosed: EventEmitter<{}>;
    /**
     * Emitted when an item is being added to the data collection
     *
     * ```html
     * <igx-combo (onAddition)='handleAdditionEvent()'></igx-combo>
     * ```
     */
    onAddition: EventEmitter<IComboItemAdditionEvent>;
    /**
     * Emitted when an the search input's input event is triggered
     *
     * ```html
     * <igx-combo (onSearchInput)='handleSearchInputEvent()'></igx-combo>
     * ```
     */
    onSearchInput: EventEmitter<{}>;
    /**
     * Emitted when new chunk of data is loaded from the virtualization
     *
     * ```html
     * <igx-combo (onDataPreLoad)='handleDataPreloadEvent()'></igx-combo>
     * ```
     */
    onDataPreLoad: EventEmitter<any>;
    /**
     * Sets the style width of the element
     *
     * ```typescript
     * // get
     * let myComboWidth = this.combo.width;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [width]='250px'></igx-combo>
     * ```
     */
    width: string;
    /**
     * Sets the style height of the element
     *
     * ```typescript
     * // get
     * let myComboHeight = this.combo.height;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [height]='400px'></igx-combo>
     * ```
     */
    height: string;
    /**
     * Controls whether custom values can be added to the collection
     *
     * ```typescript
     * // get
     * let comboAllowsCustomValues = this.combo.allowCustomValues;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [allowCustomValues]='true'></igx-combo>
     * ```
     */
    allowCustomValues: boolean;
    /**
     * Configures the drop down list height
     *
     * ```typescript
     * // get
     * let myComboItemsMaxHeight = this.combo.itemsMaxHeight;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [itemsMaxHeight]='320'></igx-combo>
     * ```
    */
    itemsMaxHeight: number;
    /**
     * Configures the drop down list width
     *
     * ```typescript
     * // get
     * let myComboItemsMaxWidth = this.combo.itemsMaxWidth;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [itemsMaxWidth] = '80'></igx-combo>
     * ```
     */
    itemsMaxWidth: any;
    /**
     * Configures the drop down list item height
     *
     * ```typescript
     * // get
     * let myComboItemHeight = this.combo.itemHeight;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [itemHeight]='32'></igx-combo>
     * ```
     */
    itemHeight: number;
    /**
     * @hidden
     */
    filteringLogic: FilteringLogic;
    /**
     * Defines the placeholder value for the combo value field
     *
     * ```typescript
     * // get
     * let myComboPlaceholder = this.combo.placeholder;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [placeholder]='newPlaceHolder'></igx-combo>
     * ```
     */
    placeholder: string;
    /**
     * Defines the placeholder value for the combo dropdown search field
     *
     * ```typescript
     * // get
     * let myComboSearchPlaceholder = this.combo.searchPlaceholder;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [searchPlaceholder]='newPlaceHolder'></igx-combo>
     * ```
     */
    searchPlaceholder: string;
    /**
     * Combo data source.
     *
     * ```html
     * <!--set-->
     * <igx-combo [data]='items'></igx-combo>
     * ```
     */
    data: any[];
    /**
     * Combo value data source propery.
     *
     * ```typescript
     * // get
     * let myComboValueKey = this.combo.valueKey;
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [valueKey]='myKey'></igx-combo>
     * ```
     */
    valueKey: string | number;
    /**
     * Combo text data source propery.
     *
     * ```typescript
     * // get
     * let myComboDisplayKey = this.combo.displayKey;
     *
     * // set
     * this.combo.displayKey = 'val';
     *
     * ```
     *
     * ```html
     * <!--set-->
     * <igx-combo [displayKey]='mydisplayKey'></igx-combo>
     * ```
     */
    displayKey: string | number;
    /**
     * Combo item group
     *
     * ```typescript
     * // get
     * let currentGroupKey = this.combo.groupKey;
     * ```
     */
    /**
     * Combo item group
     *
     * ```html
     * <!--set-->
     * <igx-combo [groupKey]='newGroupKey'></igx-combo>
     * ```
     */
    groupKey: string | number;
    /**
     * An @Input property that enabled/disables filtering in the list. The default is `true`.
     * ```html
     *<igx-combo [filterable]="'false'">
     * ```
     */
    filterable: boolean;
    /**
     * An @Input property that set aria-labelledby attribute
     * ```html
     *<igx-combo [ariaLabelledBy]="'label1'">
     * ```
     */
    ariaLabelledBy: string;
    /**
     * An @Input property that enabled/disables combo. The default is `false`.
     * ```html
     *<igx-combo [disabled]="'true'">
     * ```
     */
    disabled: boolean;
    /**
     * An @Input property that sets how the combo will be styled.
     * The allowed values are `line`, `box`, `border` and `search`. The default is `box`.
     * ```html
     *<igx-combo [type]="'line'">
     * ```
     */
    type: string;
    onArrowDown(evt: any): void;
    /**
     * @hidden
     */
    onArrowUp(evt: any): void;
    /**
     * @hidden
     */
    onInputClick(evt: any): void;
    virtualizationState: IForOfState;
    totalItemCount: number;
    /**
     * @hidden
     */
    readonly values: any[];
    /**
     * @hidden
     */
    /**
     * @hidden
     */
    filteringExpressions: any[];
    /**
     * @hidden
     */
    /**
     * @hidden
     */
    sortingExpressions: any[];
    /**
     * @hidden
     */
    protected clearSorting(field?: string | number): void;
    /**
     * Combo value
     *
     * ```typescript
     * // get
     * let comboValue = this.combo.value;
     * ```
     */
    /**
     * Combo value
     *
     * ```html
     * <!--set-->
     * <igx-combo [value]='newValue'></igx-combo>
     * ```
     */
    value: string;
    /**
     * @hidden
     */
    /**
     * @hidden
     */
    searchValue: string;
    /**
     * @hidden
     */
    /**
     * @hidden
     */
    filteredData: any[];
    /**
     * @hidden
     */
    handleKeyUp(evt: any): void;
    /**
     * @hidden
     */
    handleKeyDown(evt: any): void;
    private checkMatch();
    /**
     * @hidden
     */
    handleInputChange(event?: any): void;
    /**
     * @hidden
     */
    sort(fieldName: string | number, dir?: SortingDirection, ignoreCase?: boolean): void;
    /**
     * @hidden
     */
    getItemDataByValueKey(val: any): any;
    /**
     * @hidden
     */
    protected prepare_sorting_expression(state: any, fieldName: any, dir: any, ignoreCase: any): void;
    /**
     * @hidden
     */
    readonly dataType: string;
    private changeSelectedItem(newItem, select?);
    /**
     * @hidden
     */
    setSelectedItem(itemID: any, select?: boolean): void;
    /**
     * @hidden
     */
    isItemSelected(item: any): boolean;
    /**
     * @hidden
     */
    protected triggerSelectionChange(newSelection: any): void;
    /**
     * @hidden
     */
    triggerCheck(): void;
    /**
     * @hidden
     */
    isAddButtonVisible(): boolean;
    /**
     * @hidden
     */
    handleSelectAll(evt: any): void;
    /**
     * @hidden
     */
    addItemToCollection(): boolean;
    /**
     * @hidden
     */
    protected prepare_filtering_expression(searchVal: any, condition: any, ignoreCase: any, fieldName?: any): void;
    /**
     * @hidden
     */
    filter(term: any, condition: any, ignoreCase: any, valueKey?: any): void;
    /**
     * @hidden
     */
    ngOnInit(): void;
    /**
     * @hidden
     */
    ngAfterViewInit(): void;
    /**
     * @hidden
     */
    dataLoading(event: any): void;
    /**
     * @hidden
     */
    writeValue(value: any): void;
    /**
     * @hidden
     */
    registerOnChange(fn: any): void;
    /**
     * @hidden
     */
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    /**
     * @hidden
     */
    readonly template: TemplateRef<any>;
    /**
     * @hidden
     */
    readonly context: any;
    /**
     * @hidden
     */
    handleClearItems(event: any): void;
    toggle(): void;
    open(): void;
    close(): void;
    readonly collapsed: boolean;
    selectedItems(): any[];
    selectItems(newItems: Array<any>, clearCurrentSelection?: boolean): void;
    deselectItems(newItems: Array<any>): void;
    selectAllItems(ignoreFilter?: boolean): void;
    deselectAllItems(ignoreFilter?: boolean): void;
}
export declare class IgxComboModule {
}
